if (!require ("stats", quietly=TRUE))
    stop("package", sQuote("stats"), "is needed.  Stopping")
camp <- ts(c(
 37., 60., 71., 55., 53., 78., 53., 34., 54., 66., 63., 64., 81., 83., 82., 67., 61., 63.,        
 45., 71., 67., 47., 47., 45., 59., 58., 68., 65., 74., 48., 22., 48., 40., 45., 33., 50.,        
 47., 43., 52., 55., 41., 49., 53., 59., 49., 64., 64., 75., 63., 51., 50., 55., 56., 61.,        
 55., 51., 58., 58., 57., 61., 61., 52., 55., 60., 49., 67., 71., 61., 76., 87., 80., 87.,        
 63., 75., 68., 74., 77., 81., 64., 80., 60., 71., 55., 77., 74., 62., 46., 65., 71., 24.,        
 30., 52., 68., 52., 58., 68., 56., 58., 62., 41., 48., 56., 55., 56., 49., 50., 55., 50.,        
 44., 60., 49., 63., 56., 65., 62., 67., 64., 70., 58., 54., 37., 40., 52., 61., 44., 60.,        
 63., 56., 54., 70., 63., 63., 77., 63., 60., 47., 56., 55., 55., 66., 51., 51., 59., 55.,        
 50., 50., 56., 56., 57., 48., 55., 56., 45., 38., 40., 41., 49., 44., 51., 50., 40., 60.,        
 50., 35., 28., 38., 47., 49., 45., 57., 44., 49., 47., 54., 46., 57., 47., 48., 49., 48.,        
 50., 55., 45., 46., 55., 66., 45., 49., 60., 39., 40., 52., 53., 52., 44., 52., 44., 48.,        
 50., 47., 37., 46., 35., 39., 43., 42., 40., 49., 53., 43., 48., 22., 48., 43., 47., 43.,        
 46., 48., 38., 39., 36., 40., 48., 36., 45., 41., 34., 41., 37., 53., 54., 56., 53., 65.,        
 49., 47., 50., 34., 30., 45., 48., 47., 50., 35., 60., 48., 42., 43., 41., 41., 51., 44.,        
 62., 50., 46., 52., 50., 51., 55., 53., 59., 43., 56., 53., 49., 50., 50., 53., 58., 42.,        
 54., 44., 51., 51., 63., 53., 45., 63., 53., 59., 58., 59., 48., 39., 56., 53., 35., 51.,        
 50., 62., 49., 43., 46., 41., 35., 38., 43., 45., 39., 52., 36., 41., 38., 33., 48., 51.,        
 48., 40., 45., 42., 38., 43., 52., 42., 44., 48., 46., 51., 57., 44., 47., 53., 42., 39.,        
 39., 42., 43., 41., 49., 36., 45., 43., 48., 39., 42., 49., 35., 33., 33., 40., 48., 39.,        
 44., 44., 36., 47., 50., 42., 39., 27., 33., 36., 35., 47., 48., 29., 31., 37., 34., 40.,        
 30., 34., 42., 46., 41., 39., 35., 38., 33., 45., 36., 37., 40., 40., 38., 35., 40., 27.,        
 32., 37., 42., 39., 42., 24., 27., 30., 31., 30., 36., 30., 34., 38., 37., 36., 32., 38.,        
 48., 32., 42., 36., 33., 43., 43., 30., 27., 27., 39., 36., 37., 36., 35., 38., 40., 34.,        
 37., 32., 27., 33., 33., 43., 36., 39., 30., 31., 23., 32., 34., 43., 46., 41., 45., 37.,        
 31., 42., 48., 51., 52., 39., 39., 51., 36., 41., 34., 40., 39., 36., 44., 51., 36., 37.,        
 43., 42., 47., 45., 40., 41., 40., 32., 45., 34., 39., 21., 39., 46., 42., 29., 35., 48.,        
 33., 27., 40., 34., 33., 40., 35., 29., 35., 33., 34., 26., 30., 36., 25., 32., 36., 46.,        
 28., 35., 39., 35., 39., 39., 36., 40., 30., 38., 31., 22., 37., 40., 36., 27., 30., 35.,        
 34., 31., 46., 46., 35., 33., 40., 34., 31., 22., 25., 26., 27., 27., 26., 32., 20., 24.,        
 14., 27., 26., 30., 28., 23., 32., 34., 34., 34., 39., 44., 44., 32., 43., 43., 38., 47.,        
 40., 35., 33., 47., 47., 40., 45., 37., 29., 57., 51., 51., 50., 59., 38., 59., 53., 53.,        
 52., 56., 54., 40., 47., 42., 44., 48., 37., 40., 47., 41., 42., 24., 43., 46., 46., 36.,        
 44., 48., 40., 37., 28., 38., 36., 27., 25., 32., 38., 40., 36., 32., 33., 36., 13., 31.,        
 31., 33., 37., 31., 37., 41., 41., 40., 44., 42., 48., 33., 44., 43., 29., 41., 30., 36.,        
 27., 35., 30., 35., 36., 33., 33., 34., 35., 40., 32., 30., 33., 39., 25., 41., 28., 24.,        
 23., 22., 24., 20., 29., 27., 29., 30., 28., 22., 31., 34., 28., 34., 54., 46., 42., 53.,        
 51., 51., 42., 58., 56., 50., 47., 45., 49., 49., 54., 46., 43., 59., 66., 49., 68., 75.,        
 64., 72., 66., 66., 79., 74., 62., 65., 69., 74., 56., 82., 63., 55., 56., 53., 54., 71.,        
 62., 46., 50., 39., 47., 47., 53., 46., 52., 49., 56., 44., 48., 44., 47., 59., 42., 18.,        
 53., 42., 54., 51., 47., 37., 49., 45., 48., 50., 62., 73., 70., 66., 53., 57., 57., 54.,        
 65., 64., 59., 61., 54., 57., 63., 61., 72., 76., 55., 62., 54., 68., 42., 71., 57., 67.,        
 70., 54., 74., 67., 65., 56., 56., 54., 66., 68., 37., 55., 55., 61., 47.,  0., 27., 66.,        
 62., 53., 59., 50., 54., 52., 60., 51., 37., 57., 43., 53., 49., 51., 43., 62., 52., 49.,        
 49., 63., 61., 60., 60., 61., 65., 60., 63., 61., 64., 63., 54., 62., 60., 54., 61., 56.,        
 50., 54., 51., 46., 55., 54., 64., 57., 50., 54., 56., 50., 59., 47., 51., 62., 58., 56.,        
 56., 56., 41., 47., 42., 42., 44., 50., 49., 40., 50., 52., 42., 57., 52., 54., 58., 54.,        
 60., 57., 71., 61., 61., 57., 57., 64., 62., 58., 49., 49., 44., 47., 55., 46., 44., 62.,        
 62., 55., 55., 51., 50., 57., 61., 52., 52., 47., 49., 48., 48., 54., 57., 52., 43., 36.,        
 45., 38., 44., 47., 36., 43., 51., 36., 48., 52., 38., 45., 46., 46., 50., 50., 45., 45.,        
 45., 39., 40., 44., 44., 54., 45., 45., 35., 33., 39., 44., 46., 39., 39., 43., 50., 43.,        
 50., 48., 33., 35., 39., 41., 37., 36., 51., 41., 45., 37., 45., 44., 47., 36., 39., 39.,        
 26., 39., 47., 40., 49., 49., 47., 48., 49., 53., 35., 45., 45., 41., 38., 39., 42., 37.,        
 40., 38., 36., 26., 36., 32., 36., 30., 37., 35., 29., 35., 37., 44., 43., 39., 38., 39.,        
 15., 28., 37., 32., 31., 45., 44., 40., 38., 40., 44., 34., 42., 32., 43., 45., 40., 46.,        
 43., 39., 26., 44., 41., 25., 45., 46., 49., 45., 39., 36., 44., 47., 37., 32., 38., 38.,        
 37., 30., 37., 38., 38., 38., 40., 51., 37., 36., 44., 33., 44., 46., 42., 45., 49., 48.,        
 44., 40., 43., 41., 44., 31., 29., 31., 45., 50., 43., 48., 36., 40., 43., 34., 43., 48.,        
 47., 43., 51., 49., 48., 47., 48., 53., 54., 54., 42., 47., 53., 43., 52., 43., 28., 37.,        
 44., 49., 49., 44., 44., 53., 62., 49., 35., 46., 47., 50., 51., 46., 43., 36., 48., 52.,        
 57., 48., 45., 33., 40., 40., 40., 48., 53., 51., 59., 51., 54., 51., 59., 58., 52., 59.,        
 65., 72., 53., 52., 45., 51., 52., 50., 58., 57., 53., 57., 54., 67., 46., 50., 42., 41.,        
 51., 48., 45., 46., 50., 54., 54., 55., 54., 47., 49., 36., 34., 44., 53., 44., 28., 35.,        
 34., 41., 49., 48., 41., 39., 40., 37., 45., 52., 45., 51., 43., 51., 46., 58., 35., 43.,        
 48., 48., 47., 44., 55., 51., 20., 42., 46., 58., 56., 45., 52., 34., 36., 40., 52., 47.,        
 50., 46., 41., 43., 43., 56., 50., 48., 51., 36., 32., 38., 38., 47., 40., 36., 36., 36.,        
 38., 45., 30., 34., 35., 41., 40., 41., 31., 31., 40., 31., 49., 43., 53., 49., 54., 55.,        
 51., 62., 48., 47., 54., 48., 48., 38., 42., 48., 25., 21., 39., 45., 54., 43., 36., 42.,        
 38., 42., 39., 38., 36., 39., 38., 44., 45., 44., 42., 46., 46., 44., 33., 51., 51., 49.,        
 49., 38., 43., 47., 49., 53., 36., 39., 43., 47., 39., 37., 35., 38., 37., 45., 44., 44.,        
 49., 53., 61., 40., 40., 49., 40., 54., 46., 50., 44., 46., 55., 39., 27., 37., 33., 29.,        
 50., 37., 40., 45., 36., 46., 37., 55., 53., 57., 60., 46., 53., 40., 43., 49., 57., 38.,        
 35., 22., 23., 36., 43., 45., 46., 51., 34., 39., 50., 39., 45., 52., 42.,  0., 47., 44.,        
 45., 42., 56., 54., 45., 47., 53., 64., 41., 57., 46., 55., 48., 53., 62., 58., 66., 67.,        
 63., 60., 63., 60., 59., 48., 65., 60., 52., 39., 29., 44., 49., 53., 66., 55., 51., 51.,        
 47., 49., 50., 53., 53., 51., 41., 43., 48., 41., 51., 54., 55., 55., 44., 55., 53., 56.,        
 62., 55., 57., 43., 47., 50., 45., 50., 38., 48., 53., 51., 48., 51., 47., 45., 37., 40.,        
 44., 52., 51., 50., 44., 51., 48., 50., 47., 34., 40., 46., 42., 43., 51., 41., 43., 43.,        
 40., 40., 43., 32., 39., 34., 26., 40., 36., 41., 51., 55., 32., 30., 23., 51., 52., 59.,        
 42., 49., 62., 45., 52., 51., 53., 50., 37., 48., 44., 45., 51., 38., 43., 36., 43., 46.,        
 46., 51., 56., 59., 50., 52., 47., 40., 52., 43., 54., 53., 52., 43., 48., 32., 23., 29.,        
 44., 43., 53., 54., 48., 47., 59., 49., 53., 54., 59., 48., 62., 52., 56., 48., 60., 60.,        
 46., 47., 57., 55., 55., 61., 64., 53., 59., 62., 58., 55., 55., 39., 31., 31., 39., 41.,        
 30., 43., 41., 37., 42., 44., 48., 48., 54., 48., 44., 53., 50., 35., 32., 28., 36., 49.,        
 48., 42., 43., 43., 35., 46., 41., 48., 46., 43., 52., 41., 42., 48., 43., 41., 42., 45.,        
 48., 42., 37., 33., 48., 34., 45., 39., 32., 49., 40., 32., 40., 48., 46., 25., 45., 51.,        
 47., 51., 45., 44., 36., 47., 46., 45., 48., 47., 47., 51., 57., 58., 62., 58., 57., 53.,        
 51., 56., 60., 63., 47., 52., 51., 50., 40., 44., 50., 46., 47., 43., 45., 43., 43., 47.,        
 41., 40., 40., 36., 43., 42., 41., 44., 39., 37., 44., 43., 33., 32., 38., 29., 44., 42.,        
 43., 42., 38., 42., 40., 34., 46., 49., 50., 48., 42., 45., 34., 41., 42., 42., 47., 51.,        
 44., 48., 36., 52., 52., 45., 48., 46., 40., 46., 50., 38., 43., 49., 41., 33., 42., 47.,        
 46., 37., 45., 52., 44., 47., 50., 45., 41., 45., 42., 51., 56., 44., 59., 49., 54., 50.,        
 48., 50., 28., 20., 47., 52., 36., 44., 48., 38., 35., 43., 40., 51., 59., 53., 52., 35.,        
 49., 41., 46., 39., 37., 48., 39., 40., 32., 32., 14., 31., 44., 39., 42., 37., 38., 43.,        
 37., 21., 41., 42., 43., 51., 48., 48., 52., 51., 50., 63., 53., 59., 66., 57., 52., 53.,        
 60., 47., 43., 40., 36., 44., 46., 42., 56., 51., 42., 43., 45., 19., 31., 41., 51., 47.,        
 43., 42., 51., 44., 45., 49., 48., 47., 48., 59., 55., 44., 50., 69., 59., 45., 45., 31.,        
 40., 49., 34., 42., 44., 40., 46., 40., 40., 46., 53., 51., 52., 55., 31., 13., 32., 41.,        
 50., 49., 50., 47., 49., 57., 50., 52., 56., 59., 49., 59., 58., 58., 44., 32., 43., 49.,        
 49., 53., 49., 53., 48., 29., 43., 46., 41., 35., 44., 46., 39., 49., 42., 48., 42., 43.,        
 39., 16., 47., 37., 31., 39., 32., 32., 39., 42., 36., 37., 21., 28., 38., 40., 38., 26.,        
 35., 41., 45., 52., 49., 47., 46., 41., 38., 24., 50., 52., 43., 36., 45., 49., 33., 37.,        
 37., 51., 47., 45., 43., 47., 40., 42., 36., 42., 31., 42., 38., 47., 48., 34., 44., 34.,        
 30., 41., 23., 33., 29., 41., 40., 44., 51., 52., 48., 54., 33., 43., 48., 42., 49., 42.,        
 42., 39., 47., 48., 45., 51., 55., 54., 46., 48., 28., 46., 52., 55., 49., 47., 54., 50.,        
 42., 46., 46., 43., 46., 23., 44., 36., 50., 45., 50., 54., 45., 42., 34., 33., 40., 41.,        
 38., 24., 53., 46., 48., 55., 59., 47., 53., 46., 50., 63., 66., 55., 68., 62., 55., 44.,        
 68., 60., 55., 42., 60., 57., 60., 44., 48., 54., 37., 38., 61., 62., 50., 49., 62., 51.,        
 57., 62., 66., 63., 64., 34., 37., 59., 52., 60., 14., 66., 81., 66., 79., 66., 60., 73.,        
 67., 54., 57., 55., 46., 21., 40., 54., 53., 57., 56., 59., 48., 56., 58., 59., 59., 51.,        
 62., 51., 59., 47., 39., 44., 51., 53., 56., 54., 48., 46., 36., 34., 42., 44., 48., 50.,        
 55., 60., 62., 26., 55., 57., 46., 52., 61., 53., 51., 41., 56., 54., 52., 59., 57., 60.,        
 57., 45., 48., 45., 55., 65., 59., 62., 46., 48., 57., 65., 56., 58., 52., 55., 59., 48.,        
 61., 23., 56., 57., 61., 62., 64., 59., 55., 46., 45., 48., 45., 52., 52., 46., 45., 50.,        
 50., 50., 42., 43., 41., 44., 40., 36., 38., 39., 42., 41., 44., 45., 52., 35., 21., 44.,        
 47., 39., 48., 48., 52., 49., 48., 60., 57., 59., 48., 57., 60., 53., 53., 47., 56., 49.,        
 61., 53., 59., 53., 56., 53., 50., 42., 52., 55., 58., 56., 57., 37., 50., 44., 55., 43.,        
 52., 58., 62., 64., 62., 52., 52., 54., 48., 43., 50., 60., 41., 52., 62., 57., 68., 79.,        
 50., 70., 57., 61., 44., 47., 59., 40., 50., 55., 56., 52., 50., 44., 52., 44., 48., 48.,        
 50., 51., 49., 41., 58., 57., 64., 59., 67., 64., 53., 59., 70., 68., 62., 70., 64., 60.,        
 29., 47., 59., 64., 69., 59., 64., 52., 66., 57., 71., 46., 56., 52., 65., 65., 70., 68.,        
 63., 38., 71., 60., 56., 28., 59., 63., 52., 57., 58., 51., 45., 63., 61., 46., 40., 50.,        
 48., 53., 20., 57., 36., 45., 33., 46., 40., 47., 49., 43., 44., 38., 46., 43., 40., 32.,        
 44., 43., 43., 46., 49., 44., 46., 42., 44., 48., 40., 46., 41., 45., 51., 45., 44., 55.,        
 54., 34., 38., 52., 43., 53., 35., 41., 46., 30., 43., 46., 38., 42., 48., 39., 48., 42.,        
 27., 44., 45., 35., 37., 47., 44., 51., 37., 32., 39., 41., 41., 27., 31., 34., 38., 35.,        
 40., 46., 44., 37., 32., 31., 26., 37., 35., 33., 36., 35., 41., 25., 39., 33., 41., 40.,        
 44., 35., 42., 40., 36., 34., 27., 28., 35., 37., 41., 43., 35., 35., 38., 33., 35., 29.,        
 38., 35., 28., 23., 42., 31., 40., 38., 32., 33., 37., 40., 40., 35., 32., 33., 37., 36.,        
 33., 38., 40., 37., 39., 43., 37., 35., 37., 31., 41., 34., 39., 39., 39., 42., 43., 39.,        
 39., 37., 41., 39., 38., 36., 37., 32., 31., 33., 30., 33., 36., 38., 39., 34., 32., 33.,        
 32., 32., 44., 33., 26., 25., 33., 39., 35., 34., 26., 34., 27., 33., 35., 37., 32., 34.,        
 38., 42., 36., 30., 34., 33., 23., 34., 39., 34., 30., 36., 39., 39., 42., 39., 22., 40.,        
 36., 42., 40., 28., 27., 25., 25., 26., 25., 33., 37., 39., 33., 24., 35., 35., 32., 37.,        
 24., 32., 34., 29., 38., 37., 31., 39., 33., 35., 47., 23., 33., 25., 24., 32., 34., 36.,        
 28., 30., 41., 36., 38., 29., 36., 38., 36., 36., 39., 38., 37., 37., 31., 31., 29., 34.,        
 40., 34., 34., 38., 39., 41., 35., 44., 42., 46., 47., 40., 32., 30., 40., 37., 35., 38.,        
 37., 38., 37., 36., 40., 40., 36., 32., 34., 38., 33., 35., 33., 31., 38., 35., 38., 38.,        
 29., 25., 28., 28., 28., 30., 26., 26., 29., 27., 26., 31., 10., 22., 30., 26., 20., 30.,        
 34., 34., 30., 30., 32., 28., 28., 24., 28., 25., 31., 33., 31., 34., 29., 34., 28., 31.,        
 34., 35., 29., 31., 26., 31., 32., 37., 33., 35., 35., 39., 30., 41., 40., 38., 37., 18.,        
 42., 51., 56., 42., 42., 48., 42., 40., 46., 45., 39., 39., 38., 37., 38., 39., 53., 44.,        
 41., 41., 16., 43., 33., 42., 46., 19., 29., 40., 34., 41., 44., 34., 41., 34., 37., 40.,        
 35., 50., 45., 20., 30., 33., 38., 39., 34., 38., 28., 34., 32., 37., 50., 35., 39., 39.,        
 36., 41., 47., 43., 46., 47., 17., 31., 52., 22., 41., 58., 54., 59., 54., 49., 61., 49.,        
 56., 57., 43., 55., 36., 40., 36., 44., 32., 47., 42., 36., 39., 39., 30., 26., 30., 31.,        
 35., 34., 38., 37., 42., 42., 42., 35., 29., 38., 23., 31., 40., 36., 38., 40., 35., 26.,        
 37., 31., 34., 34., 36., 34., 35., 36., 35., 44., 44., 38., 24., 27., 37., 36., 37., 42.,        
 35., 41., 43., 43., 46., 39., 37., 33., 32., 34., 36., 27., 15., 24., 29., 27., 27., 35.,        
 34., 28., 29., 28., 34., 36., 40., 42., 45., 47., 49., 48., 35., 22., 37., 37., 36., 50.,        
 46., 44., 51., 43., 35., 48., 46., 53., 37., 45., 50., 43., 46., 38., 16., 36., 45., 38.,        
 39., 39., 41., 48., 43., 44., 46., 51., 44., 10., 35., 41., 36., 51., 34., 43., 46., 44.,        
 36., 37., 35., 43., 26., 43., 44., 43., 34., 41., 41., 41., 42., 41., 38., 44., 31., 27.,        
 23., 26., 40., 38., 39., 33., 31., 39., 42., 29., 27., 26., 35., 36., 47., 40., 34., 34.,        
 41., 42., 39., 42., 40., 36., 30., 23., 37., 40., 38., 29., 43., 23., 33., 42., 39., 40.,        
 44., 44., 41., 31., 31., 40., 37., 40., 36., 32., 37., 22., 37., 33., 45., 42., 47., 47.,        
 46., 43., 46., 43., 42., 41., 40., 24.,  9., 31., 30., 26., 32., 33., 41., 34., 37., 39.,        
 39., 38., 15., 17., 25., 32., 26., 24., 30., 25., 38., 40., 36., 39., 40., 33., 24., 32.,        
 32., 35., 37., 43., 53., 37., 16., 36., 35., 31., 40., 25., 32., 37., 33., 44., 39., 31.,        
 31., 34., 22., 35., 34., 20., 35., 25., 28., 39., 34., 38., 36., 34., 31., 31., 31., 27.,        
 41., 37., 34., 30., 30., 33., 23., 31., 30., 33., 22., 33., 12., 32., 26., 19., 33., 40.,        
 37., 35., 41., 21., 37., 27., 40., 39., 36., 37., 37., 31., 32., 32., 34., 31., 24., 17.,        
  9., 26., 16., 32., 22., 31., 32., 34., 36., 34., 38., 39., 33., 37., 35., 25., 36., 28.,        
 38., 40., 42., 40., 30., 26., 21., 33., 29., 35., 17., 35., 30., 17., 13., 38., 36., 42.,        
 38., 40., 34., 36., 35., 33., 35., 30., 30., 35., 31., 33., 37., 33., 11., 29., 31., 23.,        
  8., 26., 31., 32., 31., 30., 30., 12., 27., 31., 29., 25., 27., 30., 25., 34., 30., 33.,        
 31., 27., 26., 31., 32., 35., 30., 29., 32., 18., 27., 31., 35., 38., 40., 45., 36., 50.,        
 51., 46., 49., 44., 62., 43., 49., 53., 62., 58., 56., 31., 55., 55., 50., 47., 57., 48.,        
 49., 40., 35., 44., 27., 28., 34., 28., 30., 29., 28., 32., 43., 39., 41., 34., 36., 31.,        
 20., 34., 36., 40., 46., 23., 34., 42., 34., 37., 27., 31., 32., 34., 33., 39., 30., 33.,        
 14., 35., 45., 36., 38., 35., 36., 24., 30., 32., 24., 27., 35., 31., 13., 29., 36., 41.,        
 33., 42., 41., 33., 48., 37., 34., 45., 37., 42., 29., 39., 46., 38., 33., 17., 17., 44.,        
 39., 48., 52., 33., 48., 43., 46., 47., 54., 40., 34., 21., 43., 45., 25., 37., 46., 43.,        
 50., 43., 10., 37., 45., 40., 44., 39., 50., 50., 49., 30., 36., 36., 11.,  7., 32., 38.,        
 46., 46., 43., 46., 14., 39., 49., 35., 52., 50., 44., 51., 43., 51., 26., 46., 49., 48.,        
 42., 44., 50., 25., 44., 43., 35., 45., 49., 30., 46., 50., 50., 55., 50., 52., 53., 51.,        
 55., 33., 46., 28., 34., 32., 38., 39., 40., 42., 49., 41., 46., 45., 39., 35., 45., 40.,        
 14., 35., 37., 38., 41., 40., 49., 31., 40., 42., 43., 42., 31., 39., 35., 36., 43., 29.,        
 36., 37., 37., 43., 25., 37., 32., 39., 37., 36., 29., 29., 35., 44., 52., 50., 47., 50.,        
 49., 36., 48., 48., 44., 53., 53., 48., 49., 56., 58., 32., 49., 60., 48., 60., 46., 45.,        
 54., 59., 51., 46., 50., 58., 46., 56., 37., 55., 45., 26., 41., 51., 44., 38., 26., 23.,        
 23., 37., 36., 40., 48., 42., 48., 46., 49., 39., 49., 41., 32., 34., 26., 34., 38., 40.,        
 36., 40., 40., 43., 44., 39., 50., 19., 52., 53., 58., 42., 53., 37., 55., 56., 50., 42.,        
 42., 48., 58., 50., 55., 51., 56., 49., 50., 30., 39., 63., 55., 59., 60., 53., 48., 56.,        
 44., 49., 40., 47., 30., 53., 54., 57., 34., 29., 17., 45., 48., 55., 53., 44., 41., 57.,        
 64., 51., 58., 43., 55., 55., 57., 49., 43., 38., 41., 43., 43., 50., 36., 49., 41., 29.,        
 36., 39., 40., 45., 51., 49., 48., 53., 48., 49., 56., 56., 52., 42., 46., 45., 40., 48.,        
 40., 35., 53., 35., 50., 43., 14., 43., 45., 43., 41., 41., 40., 39., 37., 33., 31., 16.,        
 37., 41., 49., 49., 52., 50., 24., 38., 30., 50., 46., 40., 43., 47., 42., 50., 50., 52.,        
 60., 47., 52., 42., 27., 43., 39., 42., 41., 29., 44., 35., 31., 23., 28., 15., 21., 39.,        
 37., 49., 51., 53., 36., 36., 39., 33., 31., 49., 45., 43., 31.,  7., 45., 45., 47., 44.,        
 45., 55., 49., 48., 51., 50., 44., 42., 38., 24., 35., 56., 62., 68., 62., 58., 56., 57.,        
 66., 68., 71., 68., 65., 61., 56., 57., 48., 54., 52., 32., 16., 29., 44., 48., 34., 42.,        
 43., 55., 60., 71., 76., 80., 75., 35., 64., 65., 67., 57., 75., 73., 72., 59., 68., 64.,        
 56., 63., 39., 34., 20., 29., 29., 42., 52., 46., 57., 53., 57., 31., 52., 55., 43., 47.,        
 41., 43., 40., 47., 44., 42., 43., 38., 49., 40., 57., 53., 58., 34., 50., 49., 40., 49.,        
 57., 58., 60., 56., 60., 62., 63., 51., 55., 32., 42., 27., 53., 59., 51., 54., 51., 53.,        
 43., 37., 54., 46., 49., 45., 25., 23., 21., 38., 48., 47., 31., 28., 44., 21., 51., 51.,        
 48., 50., 50., 56., 43., 28., 24., 27., 34., 42., 33., 32., 37., 39., 42., 43., 46., 47.,        
 37., 28., 29., 33., 40., 50., 45., 42., 39., 40., 38., 41., 43., 44., 49., 49., 38., 22.,        
 34., 36., 27., 19., 19., 33., 39., 49., 50., 56., 49., 50., 41., 49., 49., 47., 52., 32.,        
 35., 55., 54., 55., 46., 55., 58., 55., 32., 45., 28., 48., 36., 36., 47., 50., 35., 44.,        
 46., 45., 43., 41., 47., 46., 47., 56., 45., 45., 48., 33., 32., 36., 41., 44., 35., 41.,        
 45., 47., 48., 54., 63., 46., 23., 43., 45., 40., 52., 59., 48., 45., 54., 56., 56., 50.,        
 44., 34., 49., 32., 35., 32., 27., 33., 36., 44., 42., 42., 44., 41., 42., 16., 34., 52.,        
 43., 50., 57., 53., 61., 55., 57., 60., 46., 64., 50., 52., 64., 63., 69., 66., 64., 38.,        
 44., 52., 59., 53., 62., 51., 45., 50., 62., 57., 61., 54., 60., 57., 53., 47., 39., 45.,        
 29., 45., 47., 42., 39., 39., 44., 57., 51., 52., 53., 45., 57., 46., 59., 51., 47., 36.,        
 47., 25., 12., 37., 44., 36., 36., 43., 38., 35., 42., 46., 43., 39., 21., 24., 20., 25.,        
 30., 35., 33., 39., 45., 43., 57., 55., 53., 55., 50., 18., 43., 43., 43., 43., 39., 44.,        
 36., 46., 46., 39., 47., 42., 40., 44., 33., 32., 44., 29., 36., 33., 31., 35., 26., 40.,        
 36., 41., 36., 41., 43., 43., 44., 47., 41., 43., 44., 38., 46., 43., 47., 42., 48., 40.,        
 49., 54., 53., 47., 53., 44., 32., 38., 51., 44., 40., 41., 34., 38., 40., 46., 51., 46.,        
 38., 39., 34., 41., 35., 29., 32., 37., 37., 42., 44., 43., 44., 41., 44., 47., 44., 45.,        
 42., 44., 19., 34., 34., 43., 41., 45., 50., 47., 51., 49., 47., 52., 48., 53., 41., 53.,        
 33., 28., 36., 39., 41., 37., 38., 49., 43., 52., 51., 57., 60., 44., 50., 65., 66., 74.,        
 55., 25., 51., 35., 53., 46., 23., 31., 35., 34., 17., 13., 28., 11., 24., 21., 33., 42.,        
 39., 34., 36., 39., 43., 42., 37., 25., 43., 29., 27., 33., 36., 41., 46., 41., 25., 16.,        
 15., 30., 19., 34., 40., 48., 54., 38., 50., 40., 31., 34., 44., 42., 32., 54., 31., 36.,        
 26., 30., 36., 42., 41., 40., 40., 37., 39., 39., 36., 29., 40., 47., 54., 51., 44., 44.,        
 49., 52., 49., 41., 40., 38., 33., 34., 25., 29., 35., 42., 47., 44., 47., 49., 50., 40.,        
 58., 52., 39., 41., 47., 38., 44., 38., 45., 47., 15., 23., 46., 43., 37., 36., 20., 26.,        
 29., 29., 32., 29., 34., 38., 36., 36., 40., 44., 36., 35., 33., 44., 35., 26., 35., 33.,        
  6.,  4., 35., 38., 36., 43., 42., 18., 15., 20., 30., 30., 27., 28., 25., 23., 26., 22.,        
 21., 24., 33., 30., 26., 32., 34., 38., 41., 41., 43., 36., 46., 47., 39., 40., 32., 56.,        
 46., 53., 46., 33., 44., 34., 39., 49., 53., 49., 51., 57., 21., 11., 24., 28., 28., 20.,        
 26., 30., 45., 34., 27., 40., 39., 42., 28., 34., 25.,  4., 15., 20., 26., 31., 33., 32.,        
 36., 43., 43., 44., 49., 47., 36., 30., 42., 45., 39., 16., 32., 34., 20., 35., 42., 31.,        
 47., 36., 43., 41., 51., 40., 42., 50., 42., 41., 57., 53., 47., 54., 57., 47., 51., 50.,        
 54., 45., 60., 49., 63., 60., 48., 22., 46., 60., 50., 31., 30., 49., 37., 35., 45., 34.,        
 24., 35., 35., 33., 32., 25., 26., 24., 23., 25., 22.,  4., 32., 35., 39., 33., 43., 42.,        
 30., 18., 31., 33., 39., 35., 35., 28., 42., 40., 42., 30., 19., 35., 26., 33., 41., 43.,        
 43., 48., 54., 59., 58., 35., 39., 47., 39., 31., 40., 48., 42., 33., 39., 29.,  8., 28.,        
 41., 28., 30., 33., 46., 51., 56., 55., 56., 38., 36., 49., 51., 43., 56., 41., 37., 45.,        
 46., 33., 12., 34., 33., 40., 47., 40., 44., 44., 28., 34., 45., 42., 55., 50., 54., 49.,        
 50., 54., 50., 44., 39., 29., 47., 52., 50., 43., 30., 39., 34., 44., 48., 28., 25., 31.,        
 33., 30., 28., 18., 28., 28., 30., 40., 37., 41., 49., 46., 32.,  9., 29., 33., 43., 42.,        
 35., 43., 44., 19., 22., 26., 31., 39., 42., 38., 34., 30., 38., 37., 37., 31., 31., 27.,        
 36., 37., 28., 26., 23., 22., 29., 21., 27., 21., 35., 39., 36., 30., 39., 18., 25., 34.,        
 39., 35., 43., 47., 45., 40., 52., 40., 32., 30., 25., 38., 35., 33., 30., 24., 20., 12.,        
 14., 17., 20., 23., 24., 24., 25., 29., 32., 25., 15., 26., 23., 23., 35., 24., 17., 26.,        
 23., 24., 19., 20., 21., 29., 27., 29., 34., 32., 29., 35., 34., 19., 22., 22., 19., 21.,        
 22., 26., 17.,  9., 20., 21., 15., 19., 19., 17., 18., 26., 22., 19., 23., 18., 21., 32.,        
 24., 23., 10., 22., 26., 25., 19., 31., 22., 19., 16., 24., 25., 25., 29., 33., 29., 28.,        
 28., 30., 23., 29., 21., 23., 24., 34., 27., 22., 27., 27., 23., 30., 28., 23., 27.,  9.,        
 18., 30., 24., 23., 35., 37., 23., 27., 35., 37., 51., 33., 44., 31., 34., 31., 33., 28.,        
 32., 30., 34., 21., 20., 27., 40., 32., 26., 39., 41., 38., 36., 47., 35., 38., 37., 43.,        
 31., 15., 33., 30., 36., 40., 38., 36., 41., 37., 34., 17., 28., 40., 36., 31., 36., 27.,        
 41., 37., 25., 30., 26., 30., 35., 41., 39., 36., 39., 41., 46., 46., 47., 39., 49., 58.,        
 54., 49., 40., 37., 41., 51., 41., 40., 46., 44., 48., 46., 53., 56., 41., 37., 35., 55.,        
 37., 32., 34., 41., 38., 30., 28., 24., 29., 36., 33., 41., 41., 48., 45., 39., 33., 28.,        
 35., 32., 32., 35., 34., 25., 41., 41., 39., 45., 46., 34., 33., 40., 46., 60., 58., 44.,        
 61., 51., 55., 47., 52., 49., 58., 55., 72., 46., 55., 62., 83., 99., 65., 72., 77., 56.,        
 48., 36., 50., 57., 70., 64., 58., 44., 44., 48., 55., 32., 34., 41., 46., 31., 30., 29.,        
 41., 37., 41., 34., 40., 47., 41., 38., 35., 39., 50., 63., 39., 22., 25., 26., 25., 27.,        
 25., 27., 30., 40., 41., 49., 51., 44., 41., 34., 28., 42., 43., 33., 50., 45., 55., 60.,        
 66., 50., 59., 72., 61., 65., 65., 69., 54., 70., 61., 64., 70., 91., 78., 76., 59., 64.,        
 68., 84., 87., 84., 65., 64., 49., 64., 72., 79., 70., 56., 54., 53., 53., 48., 64., 49.,        
 48., 64., 64., 69., 58., 68., 68., 60., 66., 50., 56., 54., 38., 44., 41., 48., 44., 50.,        
 56., 67., 54., 56., 56., 43., 42., 29., 11., 31., 44., 44., 51., 43., 59., 56., 47., 43.,        
 51., 72., 47., 57., 52., 48., 44., 51., 48., 38., 44., 36., 40., 39., 38., 39., 37., 47.,        
 29., 37., 55., 49., 43., 48., 54., 63., 32., 29., 46., 52., 30., 49., 47., 43., 45., 42.,        
 42., 46., 43., 37., 35., 34., 37., 35., 46., 34., 38., 47., 52., 48., 31., 49., 45., 39.,        
 47., 46., 33., 35., 38., 40., 26., 36., 33., 40., 45., 41., 45., 53., 51., 41., 49., 41.,        
 48., 54., 45., 37., 46., 44., 47., 41., 48., 36., 41., 56., 52., 57., 67., 53., 49., 54.,        
 56., 54., 56., 57., 58., 43., 58., 63., 61., 61., 59., 57., 53., 53., 38., 49., 33., 39.,        
 17., 28., 23., 25., 26., 25., 22., 28., 25., 29., 34., 29., 29., 30., 23., 31., 37., 35.,        
 33., 32., 42., 38., 32., 33., 29., 26., 26., 30., 35., 30., 33., 36., 37., 39., 37., 35.,        
 41., 37., 39., 40., 44., 40., 36., 31., 34., 48., 43., 49., 38., 47., 40., 40., 47., 43.,        
 36., 40., 43., 40., 46., 49., 38., 39., 32., 35., 39., 34., 44., 39., 42., 48., 46., 36.,        
 37., 37., 34., 40., 39., 39., 33., 37., 38., 48., 33., 39., 39., 41., 36., 37., 41., 36.,        
 24., 37., 41., 50., 39., 31., 46., 51., 36., 54., 48., 48., 34., 38., 43., 33., 33., 42.,        
 34., 36., 25., 31., 20., 32., 18., 28., 32., 34., 28., 33., 23., 21., 14., 13., 16., 20.,        
 16., 20., 19., 17., 16., 16., 12., 23., 26., 21., 26., 25., 26., 18., 35., 33., 33., 26.,        
 23., 39., 29., 26., 32., 33., 36., 31., 32., 30., 38., 31., 25., 32., 38., 31., 23., 15.,        
 27., 39., 28., 38., 34., 38., 38., 36., 34., 41., 36., 45., 55., 49., 58., 55., 55., 41.,        
 54., 56., 54., 49., 49., 52., 43., 22., 42., 51., 43., 56., 58., 56., 61., 56., 58., 23.,        
 45., 66., 55., 57., 47., 55., 48., 29., 14., 31., 29., 24., 22., 20., 26., 33., 37., 34.,        
 44., 38., 41., 41., 47., 43., 33., 38., 45., 40., 50., 43., 51., 40., 39., 53., 54., 54.,        
 51., 33., 45., 36., 43., 45., 46., 46., 25., 15., 19., 37., 35., 38., 31., 35., 31., 38.,        
 39., 33., 25., 34., 35., 41., 51., 37., 41., 43., 50., 39., 31., 30., 29., 47., 38., 32.,        
 29., 24., 43., 41., 30., 31., 30., 31., 39., 27., 36., 38., 19., 23., 24., 33., 28., 27.,        
 15., 32., 18., 29., 37., 44., 34., 33., 26., 37., 43., 36., 47., 45., 41., 43., 48., 20.,        
 29., 34., 29., 29., 31., 17., 37., 37., 42., 44., 38., 37., 34., 25., 39., 40., 47., 43.,        
 49., 53., 41., 46., 50., 49., 41., 39., 28., 24., 17., 32., 25., 29., 31., 19., 25., 17.,        
 30., 31., 32., 11., 35., 31., 35., 30., 19., 31., 33., 32., 18., 39., 35., 39., 43., 41.,        
 27., 30., 29., 27., 27., 28., 27., 13., 21., 14., 24., 22., 20., 33., 31., 27., 35., 36.,        
 28., 37., 33., 29., 38., 33., 37., 49., 43., 35., 43., 43., 35., 40., 46., 46., 50., 43.,        
 52., 27., 45., 35., 51., 52., 45., 42., 48., 54., 35., 48., 43., 42., 41., 53., 49., 46.,        
 47., 57., 40., 27., 34., 38., 34., 35., 46., 38., 54., 52., 43., 35., 33., 42., 40., 43.,        
 28., 36., 35., 38., 45., 42., 37., 47., 45., 36., 41., 45., 43., 28., 14., 35., 34., 37.,        
 39., 37., 44., 37., 35., 41., 41., 41., 40., 37., 47., 50., 44., 44., 47., 56., 44., 51.,        
 48., 54., 41., 40., 46., 50., 26., 36., 24., 30., 34., 32., 32., 38., 32., 32., 28., 37.,        
 35., 41., 33., 37., 43., 42., 38., 39., 40., 43., 44., 42., 48., 42., 24., 29., 31., 37.,        
 26., 33., 27., 38., 27., 33., 36., 31., 39., 38., 30., 37., 46., 41., 46., 47., 38., 23.,        
 27., 35., 47., 38., 43., 37., 60., 37., 58., 50., 54., 49., 54., 57., 54., 55., 53., 47.,        
 36., 56., 54., 51., 34., 37., 54., 45., 48., 41., 51., 51., 58., 61., 48., 57., 55., 48.,        
 41., 47., 32., 42., 47., 22., 49., 48., 52., 45., 38., 44., 44., 57., 47., 50., 43., 54.,        
 39., 34., 49., 54., 50., 43., 44., 56., 54., 57., 61., 52., 43., 63., 61., 72., 72., 43.,        
 76., 71., 61., 63., 72., 55., 46., 63., 55., 66., 66., 51., 60., 64., 54., 56., 67., 73.,        
 52., 59., 69., 70., 51., 67., 61., 62., 56., 59., 51., 59., 32., 31., 55., 57., 69., 60.,        
 53., 55., 64., 68., 60.),
start = -3435, end = 1969, frequency = 1)
             
